@@ -5,10 +5,8 @@ __email__ = 'robbert@xkls.nl'
 __licence__ = 'GPL v3'
 
 
-from ybe import read_ybe_file
+from ybe import read_ybe_file, YbeToQTI_1p2
 from importlib import resources
-from ybe.lib.qti_writer import write_qti_zip, ConvertCanvasEquations
-
 
 # read the provided example Ybe.
 with resources.path('ybe.data', 'example_database.ybe') as path:
@@ -17,8 +15,5 @@ with resources.path('ybe.data', 'example_database.ybe') as path:
 # change to your preference
 output_dir = '/tmp/qti_output/'
 
-# write a generic QTI.
-write_qti_zip(ybe_exam, output_dir + 'qti.zip')
-
 # Write a QTI with the equations converted to the way Canvas (https://canvas.instructure.com) likes it.
-write_qti_zip(ybe_exam, output_dir + 'qti_canvas.zip', text_formatter=ConvertCanvasEquations())
+YbeToQTI_1p2(convert_canvas_equations=True).convert(ybe_exam, output_dir + 'new.zip')
